@@ -12,8 +12,10 @@
    GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  */
+   along with this software; see the file COPYING.  If not, a copy
+   can be downloaded from http://www.gnu.org/licenses/gpl.html, or
+   obtained by writing to the Free Software Foundation, Inc.,
+   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  */
 
 /*------------------------------------------------------------*/
 
@@ -30,7 +32,7 @@ void perspective(TrformStr *TrPtr, pPrefs *prefs)
 	double  	alpha, beta, gammar; 				// Angles in rad
 	double		x_off, y_off, d;
 	double		a;
-	pt_int32	destwidth, destheight;
+	uint32_t   	destwidth, destheight;
 	fDesc		fD;
 
 	void		*params[4];		// Parameters for perspective control functions
